@@ -1,4 +1,4 @@
-# $Id: Aselect.pm 44542 2016-01-20 14:36:35Z wsl $
+# $Id: Aselect.pm 38052 2012-10-25 12:19:49Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect.pm $
 
 use utf8;
@@ -50,7 +50,6 @@ sub handler {
 	my $credentials = $self->kerberos_principal
 		? new Aselect::UI::Combined(cfg => $rsc, success => $success)
 		: new Aselect::UI::Password(cfg => $rsc, success => $success);
-	my $validate = new Aselect::WS::ValidateCASv2(cfg => $rsc);
 
 	my $root = new Xyzzy::Directory(cfg => $rsc,
 		handler => $static,
@@ -72,8 +71,7 @@ sub handler {
 				subdirs => { server => $server },
 			),
 			validate => new Aselect::WS::ValidateCASv1(cfg => $rsc),
-			serviceValidate => $validate,
-			proxyValidate => $validate,
+			serviceValidate => new Aselect::WS::ValidateCASv2(cfg => $rsc),
 		}
 	);
 	return new Aselect::UI::Windshield(cfg => $rsc, handler => $root);
@@ -117,8 +115,8 @@ always accessed with the same name (in the HTTP Host: request header) you
 should also set AselectServerID and AselectCookieDomain on all nodes (to a
 value that is the same on all nodes).
 
-Unless you have perfect confidence in your clocks and your NTP solution,
-consider setting CryptoClockJitter as well.
+Unless you have perfect confidence in your NTP solution, consider setting
+CryptoClockJitter as well.
 
 =head1 CONFIGURATION
 
@@ -137,7 +135,7 @@ Available options:
 =item AselectServerID I<id>
 
 Identifier used by the A-Select protocol that identifies this server
-instance. If you run multiple A-Select servers in a cluster, this
+instance. If you are running multiple A-Select servers in a cluster, this
 parameter should be the same across all the nodes in the cluster.
 
 =item AselectOrganization I<name>
@@ -151,9 +149,6 @@ can specify using this parameter.
 The DNS-domain the session/settings HTTP cookies are attached to. Useful if
 you have multiple servers with different hostnames but a common domain.
 
-If no cookie domain is set, determining the cookie scope is left to the
-browser.
-
 =item AselectAttributes I<name> [I<base>]
 
 Declares an attribute set (also known as a ‘policy’ or ‘attribute release
@@ -218,10 +213,10 @@ The list of languages that are supported by the templates. Each language
 should be specified as a two-letter (ISO 639) code corresponding to the
 HTTP Accept-Language header.
 
-If (and only if) this parameter is specified, templates are loaded from the
-subdirectory of StylesheetDir that corresponds to the language that is
-negotiated using request headers and/or cookies. Similarly, static content
-is loaded from a subdirectory of ContentDir.
+If this parameter is specified, templates are loaded from the subdirectory
+of StylesheetDir that corresponds to the language that is negotiated using
+request headers and/or cookies. Similarly, static content is loaded from a
+subdirectory of ContentDir.
 
 =item CryptoSecret I<long random string>
 
@@ -230,28 +225,22 @@ be a long string (at least 64 characters) of random characters from a
 cryptographically sound origin. Leaking this key allows an attacker to
 impersonate any user on the system.
 
-If you run multiple A-Select servers in a cluster, this key should
+If you are running multiple A-Select servers in a cluster, this key should
 be the same across all nodes.
 
-Changing this configuration setting will cause extant sessions that were
-created with a different (old) value to be invalid, effectively logging
-all users out.
-
 =item AselectSecret
 
 A deprecated name for CryptoSecret. Please use CryptoSecret instead.
 
 =item CryptoClockJitter I<interval>
 
-If you run multiple A-Select servers in a cluster, clocks in the
+If you are running multiple A-Select servers in a cluster, clocks in the
 cluster MUST be synced using a protocol like NTP. However, even if NTP is
 in use, small time differences may still occur.
 
 This parameter configures the maximum clock difference that the server
 accepts. A value of 1 second should be more than enough in most cases.
 
-Defaults to 0.
-
 =item ServiceFilter [I<regex>]
 
 A filter to be applied to CAS service URLs and unsigned A-Select requests.
@@ -301,8 +290,6 @@ Forces all applications to use https by rewriting all service URLs as they
 come in. Even if a sign-in is attempted on a http site, the user will be
 redirected back to the https version upon completing their sign-in.
 
-Defaults to ‘no’.
-
 =item AselectSessionTimeout I<interval>
 
 How long an SSO session should last. Default is 10 hours.
@@ -336,15 +323,11 @@ Set the Strict-Transport-Security HTTP header on all pages, to ensure that
 browsers always use https when accessing the A-Select server. See
 https://en.wikipedia.org/wiki/HTTP_Strict_Transport_Security for details.
 
-Default is to not issue Strict-Transport-Security headers.
-
 =item AselectLoginURL I<url>
 
 Set the URL that is passed to application when they request authentication.
 This should point at a variation on C<https://sso.example.com/login>.
 
-The default is to automatically construct the URL from the request.
-
 =item StylesheetDir I<directory>
 
 A directory containing XSLT templates for the user-facing pages.
@@ -399,49 +382,16 @@ LDAPCApath.
 
 =item LDAPAttribute I<uid>
 
-LDAP attribute containing the login principal of the user. Usually ‘uid’,
-which is also the default.
+LDAP attribute containing the login principal of the user. Usually ‘uid’.
 
-=item LDAPFilter I<(...)>
+=item LDAPFilter I<uid>
 
-An additional filter to be applied to users logging in. Example:
+An additional filter to be applied to user logging in. Example:
 
 	LDAPFilter (organizationalStatus=staff)
 
 To allow only staff to log in.
 
-=item LDAPExpiryAttributes
-
-LDAP attributes that, if any are present for a user, cause a warning to be
-displayed when the user starts an SSO session. Each attribute must be
-specified on a seperate line. These are passed to the stylesheet in an
-<expire> element. An optional name for the stylesheet element can be
-specified for each attribute, separated from the attribute with whitespace.
-If no element name is specified, the attribute name is used as the element
-name.
-
-If any LDAP attribute names are given directly after the
-LDAPExpiryAttributes keyword, these form the list of attribute names that
-indicate whether password expiration reminders need to be given to the
-user. The presence of any of these attributes will trigger the warning to
-the user. If no attribute names are specified in this way, the server
-defaults to the list of attributes that are displayed.
-
-See below for an example.
-
-=item LockClientIP I<yes/no>
-
-Whether to lock sessions to the client's IP address. Provides extra
-security but may be inconvenient in environments where the IP address of a
-client changes often (for example, due to wireless roaming) or in
-dual-stack IPv4/IPv6 setups.
-
-Changing this configuration setting will cause extant sessions that were
-created with the inverse (old) value to be considered invalid, effectively
-logging all users out.
-
-Defaults to ‘yes’.
-
 =back
 
 =head1 EXAMPLE
@@ -460,15 +410,6 @@ Sample configuration file:
 	LDAPPassword hunter2
 	LDAPCApath /etc/ssl/certs
 
-	# If the passwordExpirationStage LDAP attribute is present,
-	# the user will be warned and the passwordLastChanged,
-	# passwordExpirationStage and passwordExpirationFinalDay
-	# attributes are passed to the stylesheet.
-	LDAPExpiryAttributes passwordExpirationStage
-		passwordLastChanged last-change
-		passwordExpirationStage stage
-		passwordExpirationFinalDay final-day
-
 	KerberosPrincipal HTTP/sso.example.org@DOMAIN.EXAMPLE.ORG
 
 	CryptoSecret zxnrbl
