@@ -1,4 +1,4 @@
-# $Id: Request.pm 43917 2015-09-22 08:37:08Z wsl $
+# $Id: Request.pm 38478 2013-01-14 11:39:21Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Login/Request.pm $
 
 use strict;
@@ -37,24 +37,18 @@ param service => sub {
 	my $cfg = $self->cfg;
 
 	$_ = normalize_url($_);
-	unless(valid_http_url($_)) {
-		warn "rejecting '$_' as a valid service because it is malformed\n";
-		die $self->errorpage('service');
-	}
+	die $self->errorpage('service')
+        unless valid_http_url($_);
 
 	my $re = $cfg->urlfilter;
-	unless($_ =~ $re) {
-		warn "rejecting '$_' as a valid service because it does not match the configured ServiceFilter\n";
-		die $self->errorpage('service');
-	}
+	die $self->errorpage('service')
+		unless $_ =~ $re;
 
 	$re = $cfg->servicefilter;
-	unless($_ =~ $re) {
-		warn "rejecting '$_' as a valid service because it does not match the list of allowed services configured under ServiceFilter\n";
-		die $self->errorpage('service');
-	}
+	die $self->errorpage('service')
+		unless $_ =~ $re;
 
-	$_ = $self->apply_https_everywhere($_);
+	s/^http:/https:/ if $cfg->https_everywhere;
 };
 
 param lt => sub {
@@ -76,8 +70,10 @@ field effective_warn => sub {
 field effective_remember => sub {
 	my $self = shift;
 	return 'true' unless defined $self->rid || defined $self->service;
-	return bool_string($self->bool_param('remember') // 0)
-		if $self->nonce;
+	if($self->nonce) {
+		my $remember = $self->bool_param('remember');
+		return bool_string($remember) if defined $remember;
+	}
 	return $self->new_remember;
 };
 
