@@ -1,4 +1,4 @@
-# $Id: Request.pm 42268 2014-09-22 14:05:34Z wsl $
+# $Id: Request.pm 37889 2012-09-28 10:04:21Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Request.pm $
 
 use strict;
@@ -14,15 +14,11 @@ use Xyzzy::Util qw(parse_bool);
 use Aselect::Request -self;
 
 field gssapi => sub { shift->cfg->gssapi };
-field client_ip => sub {
-	my $self = shift;
-	return $self->cfg->lock_client_ip ? $self->remote_addr : '';
-};
 
 # create a new session, either anonymous or with uid
 sub create_session {
 	my $uid = shift;
-	my $ip = $self->client_ip;
+	my $ip = $self->remote_addr;
 	my ($exp, $salt, $token) = $self->crypto->create_token('s'.$ip, $uid // ());
 	return new Aselect::UI::Ticket(token => $token, uid => $uid, salt => $salt, expiration => $exp, cfg => $self->cfg);
 }
@@ -31,7 +27,7 @@ sub create_session {
 field cur_session => sub {
 	my $self = shift;
 	if(my $cookie = $self->cookie('session')) {
-		my $ip = $self->client_ip;
+		my $ip = $self->remote_addr;
 		if(my ($exp, $salt, $uid) = eval { $self->crypto->check_token('s'.$ip, $cookie, $self->cfg->session_timeout) }) {
 			return new Aselect::UI::Ticket(token => $cookie, uid => $uid, salt => $salt, expiration => $exp, cfg => $self->cfg);
 		}
@@ -109,7 +105,7 @@ field lang => sub {
 		}
 	}
 
-	my $h = lc($self->http('Accept-Language') // '');
+	my $h = lc($self->http('Accept-Language'));
 	$h =~ s/\s//g;
 
 	my $curlang = $supported[0];
