@@ -1,4 +1,4 @@
-# $Id: Request.pm 42589 2014-11-21 09:44:55Z wsl $
+# $Id: Request.pm 36638 2012-03-03 14:33:20Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Success/Request.pm $
 
 use strict;
@@ -50,19 +50,3 @@ field cred_url => sub {
 		return $self->script_url . '/status';
 	}
 };
-
-field expiration_warning => sub {
-	my $self = shift;
-	# Only bother the user when initially signing in
-	my $previous = $self->cur_session;
-	return undef if $previous && $previous->token eq $self->new_session->token;
-	my $exp = eval { $self->dir->expiration($self->uid) };
-	warn $@ if $@;
-	return $exp;
-};
-
-field redirect_ok => sub {
-	my $self = shift;
-	return ($self->effective_warn eq 'false' || $self->nonce)
-		&& !$self->expiration_warning;
-};
