@@ -1,4 +1,4 @@
-# $Id: URL.pm 39280 2013-04-22 14:45:43Z wsl $
+# $Id: URL.pm 37941 2012-10-04 15:40:22Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/URL.pm $
 
 use utf8;
@@ -13,12 +13,12 @@ use Exporter qw(import);
 our @EXPORT = qw(normalize_url valid_http_url acl_to_re_url $fqdn $fqdnport $hostport);
 
 our $fqdn = qr{(?:xn--)?[a-z0-9]+(?:-[a-z0-9]+)*(?:\.(?:xn--)?[a-z0-9]+(?:-[a-z0-9]+)*)+}i;
-our $port = qr{:(?:[1-9][0-9]{0,4}|\*)};
+our $port = qr{:[1-9][0-9]{0,4}};
 our $fqdnport = qr{$fqdn$port?};
 our $hostport = qr{(?:\[[0-9a-f.:]+\]|$fqdn|localhost)$port?}i;
 
 sub valid_http_url {
-	return shift =~ m{^https?://$hostport?(?:[/?#]|$)}io;
+	return shift =~ qr{^https?://$hostport?(?:[/?#]|$)}o;
 }
 
 sub normalize_url {
@@ -39,7 +39,7 @@ sub acl_to_re_url {
 
 	my $url = $orig;
 	my $re = quotemeta($url);
-	$url =~ s{^(\w+://)}{};
+	$url =~ s{^(\w+)://}{};
 
 	my $scheme = $1
 		? qr{$1}
@@ -47,15 +47,9 @@ sub acl_to_re_url {
 
 	$url =~ s{^(\.($fqdnport)|$hostport)([/?#]|$)}{$3}
 		or die "can't parse url '$orig'\n";
-	my ($hostpart, $fqdnpart) = ($1, $2);
-	my $domain;
-	if($fqdnpart) {
-		my $wildpart = ($fqdnpart =~ s/:\*$//) ? qr{(?::\d+)?} : '';
-		$domain = qr{(?:(?:[a-z0-9.-]+)\.)?\Q$fqdnpart\E$wildpart}i
-	} else {
-		my $wildpart = ($hostpart =~ s/:\*$//) ? qr{(?::\d+)?} : '';
-		$domain = qr{\Q$hostpart\E$wildpart}i;
-	}
+	my $domain = $2
+		? qr{(?:(?:[a-z0-9.-]+)\.)?\Q$2\E}i
+		: qr{\Q$1\E}i;
 
 	die "in '$orig': unable to handle queries or fragments\n"
 		if $url =~ m{[?#]};
